﻿using Microsoft.SharePoint.Client;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace KevinTimmerman.UC2016.AuthenticationMethods
{
    class Program
    {
        static void Main(string[] args)
        {
            string siteUrl = "https://kevintimmerman.sharepoint.com/sites/UnityConnect2016-1";

            var authManager = new OfficeDevPnP.Core.AuthenticationManager();
            using (ClientContext context = authManager.GetSharePointOnlineAuthenticatedContextTenant(siteUrl, Constants.Username, Constants.Password))
            {
                context.Load(context.Web, w => w.Title);
                context.ExecuteQuery();
                Console.WriteLine("Title via SPO Credentials: " + context.Web.Title);
            }

            using (ClientContext context = authManager.GetAppOnlyAuthenticatedContext(siteUrl, "YOUR CLIENT ID HERE", "YOUR CLIENT SECRET HERE"))
            {
                context.Load(context.Web, w => w.Title);
                context.ExecuteQuery();
                Console.WriteLine("Title via App Only Credentials: " + context.Web.Title);
            }

            var targetSite = new Uri(siteUrl);
            string realm = TokenHelper.GetRealmFromTargetUrl(targetSite);

            var token = TokenHelper.GetAppOnlyAccessToken(TokenHelper.SharePointPrincipal, targetSite.Authority, realm);
            
            using (ClientContext context = new ClientContext(targetSite))
            {
                context.AuthenticationMode = ClientAuthenticationMode.Anonymous;
                context.FormDigestHandlingEnabled = false;
                context.ExecutingWebRequest += delegate(object sender, WebRequestEventArgs webRequestEventArgs)
                {
                    webRequestEventArgs.WebRequestExecutor.RequestHeaders["Authorization"] =
                        "Bearer " + token.AccessToken;
                };

                var web = context.Web;
                context.Load(context.Web, w => w.Title);
                context.ExecuteQuery();
                Console.WriteLine("Title via App Only: " + context.Web.Title);
            }

            Console.ReadLine();

            //<AppPermissionRequests>
            //<AppPermissionRequest Scope="http://sharepoint/content/tenant" Right="FullControl"/>
            //</AppPermissionRequests>
        }
    }
}
