﻿using Microsoft.SharePoint.Client;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace KevinTimmerman.UC2016.LoadVSLoadQuery
{
    class Program
    {
        static void Main(string[] args)
        {
            List<TimeSpan> timesLoad = new List<TimeSpan>();
            List<TimeSpan> timesLoadQuery = new List<TimeSpan>();
            int numberOfTests = 10;

            Console.WriteLine("===== Load =====");
            for (int i = 0; i < numberOfTests; i++)
            {
                var timespan = GetViaLoad();
                Console.WriteLine(string.Format("#{0} time taken: {1}", i, timespan));
                timesLoad.Add(timespan);
            }
            var executeQueryAvg = GetAverage(timesLoad);
            Console.WriteLine("Average time taken: " + executeQueryAvg);
            Console.WriteLine("");

            Console.WriteLine("===== LoadQuery =====");
            for (int i = 0; i < numberOfTests; i++)
            {
                var timespan = GetViaLoadQueryQuery();
               Console.WriteLine(string.Format("#{0} time taken: {1}", i, timespan));
                timesLoadQuery.Add(timespan);
            }
            var loadQueryAvg = GetAverage(timesLoadQuery);
            Console.WriteLine("Average time taken: " + loadQueryAvg);
            Console.WriteLine("");

            var percentageDifference = 100 - (decimal)loadQueryAvg.Ticks / (decimal)executeQueryAvg.Ticks * 100;
            Console.WriteLine("Performance difference Load vs LoadQuery users: " + percentageDifference.ToString("F") + "%");

            Console.ReadLine();
        }

        static TimeSpan GetViaLoad()
        {
            using (ClientContext context = new ClientContext("https://kevintimmerman.sharepoint.com/sites/unityconnect2016-2"))
            {
                var password = new System.Security.SecureString();
                Array.ForEach(Constants.Password.ToCharArray(), (c) => { password.AppendChar(c); });
                SharePointOnlineCredentials credentials = new SharePointOnlineCredentials(Constants.Username, password);
                context.Credentials = credentials;
                context.ExecuteQuery(); // This will do nothing other then validating the credentials so that it's not done during the time-measured call below

                var start = System.DateTime.UtcNow.Ticks;
                context.Load(context.Site.RootWeb.SiteUsers, s => s.Include(u => u.IsSiteAdmin, u => u.LoginName));
                //context.Load(context.Site.RootWeb.Lists, s => s.Include(l => l.Hidden, l => l.Title));
                context.ExecuteQuery();

                var siteAdmins = context.Site.RootWeb.SiteUsers.Where(u => u.IsSiteAdmin).ToList();
                //var hiddenLists = context.Site.RootWeb.Lists.Where(u => u.Hidden).ToList();

                var end = System.DateTime.UtcNow.Ticks;
                return TimeSpan.FromTicks(end - start);
            }
        }

        static TimeSpan GetViaLoadQueryQuery()
        {
            using (ClientContext context = new ClientContext("https://kevintimmerman.sharepoint.com/sites/unityconnect2016-2"))
            {
                var password = new System.Security.SecureString();
                Array.ForEach(Constants.Password.ToCharArray(), (c) => { password.AppendChar(c); });
                SharePointOnlineCredentials credentials = new SharePointOnlineCredentials(Constants.Username, password);
                context.Credentials = credentials;
                context.ExecuteQuery(); // This will do nothing other then validating the credentials so that it's not done during the time-measured call below

                var start = System.DateTime.UtcNow.Ticks;
                var siteAdmins = context.LoadQuery(context.Site.RootWeb.SiteUsers.Where(u => u.IsSiteAdmin).Include(u => u.IsSiteAdmin, u => u.LoginName));
                //var hiddenLists = context.LoadQuery(context.Site.RootWeb.Lists.Where(l => l.Hidden).Include(l => l.Hidden, l => l.Title));
                context.ExecuteQuery();
                var end = System.DateTime.UtcNow.Ticks;
                return TimeSpan.FromTicks(end - start);
            }
        }

        static TimeSpan GetAverage(List<TimeSpan> timeSpanList)
        {
            double doubleAverageTicks = timeSpanList.Average(timeSpan => timeSpan.Ticks);
            long longAverageTicks = Convert.ToInt64(doubleAverageTicks);
            return new TimeSpan(longAverageTicks);
        }
    }
}
