﻿using Microsoft.SharePoint.Client;
using Microsoft.SharePoint.Client.Utilities;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;

namespace KevinTimmerman.UC2016.QueryBatching
{
    class Program
    {
        static List<string> userArrayToResolve;

        static void Main(string[] args)
        {
            userArrayToResolve = new List<string>();

            for (int i = 1; i < 1000; i++)
            {
                userArrayToResolve.Add("Test" + i + "@kevintimmerman.onmicrosoft.com");
            }

            Console.WriteLine("===== All in One Go =====");
            var timespan = ResolveAllInOneGo();
            Console.WriteLine(string.Format("Time taken: {0}", timespan));

            Console.WriteLine("--Press enter to continue--");
            Console.ReadLine();

            Console.WriteLine("===== All in Batches =====");
            var timespan2 = ResolveAllInBatches();
            Console.WriteLine(string.Format("Time taken: {0}", timespan2));

            Console.ReadLine();
        }

        static TimeSpan ResolveAllInOneGo()
        {
            using (ClientContext context = new ClientContext("https://kevintimmerman.sharepoint.com/sites/unityconnect2016-2"))
            {
                var password = new System.Security.SecureString();
                Array.ForEach(Constants.Password.ToCharArray(), (c) => { password.AppendChar(c); });
                SharePointOnlineCredentials credentials = new SharePointOnlineCredentials(Constants.Username, password);
                context.Credentials = credentials;
                context.ExecuteQuery(); // This will do nothing other then validating the credentials so that it's not done during the time-measured call below

                var start = System.DateTime.UtcNow.Ticks;

                foreach (string userName in userArrayToResolve)
                {
                    Console.WriteLine("Adding user " + userName);
                    Utility.ResolvePrincipal(context, context.Web, userName, PrincipalType.User, PrincipalSource.All, null, false);
                }

                try
                {
                    context.ExecuteQuery();
                }
                catch (Exception ex)
                {
                    Console.WriteLine(ex.Message);
                }

                var end = System.DateTime.UtcNow.Ticks;
                return TimeSpan.FromTicks(end - start);
            }
        }

        static TimeSpan ResolveAllInBatches()
        {
            using (ClientContext context = new ClientContext("https://kevintimmerman.sharepoint.com/sites/unityconnect2016-2"))
            {
                var password = new System.Security.SecureString();
                Array.ForEach(Constants.Password.ToCharArray(), (c) => { password.AppendChar(c); });
                SharePointOnlineCredentials credentials = new SharePointOnlineCredentials(Constants.Username, password);
                context.Credentials = credentials;
                context.ExecuteQuery(); // This will do nothing other then validating the credentials so that it's not done during the time-measured call below

                Dictionary<string, PrincipalInfo> finalResults = new Dictionary<string, PrincipalInfo>();
                Dictionary<string, object> batchResults = new Dictionary<string, object>();

                var start = System.DateTime.UtcNow.Ticks;
                int pager = 0;
                int overallCounter = 0;
                int usersPerBatch = 100;

                foreach (string userName in userArrayToResolve)
                {
                    pager++;
                    overallCounter++;

                    Console.WriteLine("Adding user " + userName);
                    batchResults.Add(userName, Utility.ResolvePrincipal(context, context.Web, userName, PrincipalType.User, PrincipalSource.All, null, false));

                    if (pager == usersPerBatch || overallCounter == userArrayToResolve.Count())
                    {
                        Console.ForegroundColor = ConsoleColor.Yellow;
                        Console.WriteLine("Performing executeQuery");
                        Console.ResetColor();

                        try
                        {
                            context.ExecuteQuery();

                            foreach (var kvp in batchResults)
                            {
                                var principal = ((ClientResult<PrincipalInfo>)kvp.Value);
                                finalResults.Add(kvp.Key, principal.Value);
                            }
                        }
                        catch (Exception ex)
                        {
                            Console.WriteLine(ex.Message);
                        }

                        batchResults.Clear();
                        pager = 0;
                    }
                }                

                var end = System.DateTime.UtcNow.Ticks;
                return TimeSpan.FromTicks(end - start);
            }
        }
    }
}
