﻿using Microsoft.SharePoint.Client;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Text;
using System.Threading.Tasks;

namespace KevinTimmerman.UC2016.SiteExistsForbidden
{
    class Program
    {
        static void Main(string[] args)
        {
            string siteUrl = "https://kevintimmerman.sharepoint.com/sites/doesReallyNotExist";

            try
            {
                var authManager = new OfficeDevPnP.Core.AuthenticationManager();
                using (ClientContext context = authManager.GetAppOnlyAuthenticatedContext(siteUrl, "YOUR CLIENT ID HERE", "YOUR CLIENT SECRET HERE"))
                {
                    //Gives token request failed
                }
            }
            catch (Exception ex)
            {
                Console.WriteLine(ex.Message);
            }

            Uri targetSite = new Uri(siteUrl);
            string realm = TokenHelper.GetRealmFromTargetUrl(new Uri("https://kevintimmerman.sharepoint.com"));//Get from root site should always work

            var token = TokenHelper.GetAppOnlyAccessToken(TokenHelper.SharePointPrincipal, targetSite.Authority, realm);

            using (ClientContext context = new ClientContext(targetSite))
            {
                try
                {
                    context.Load(context.Web, w => w.Title);
                    context.ExecuteQuery();
                    Console.WriteLine("Title via App Only Credentials: " + context.Web.Title);
                }
                catch (WebException wex)
                {
                    var response = wex.Response as HttpWebResponse;
                    Console.WriteLine(response.StatusCode);
                }
                catch (Exception ex)
                {
                    Console.WriteLine(ex.Message);
                }
            }

            Console.WriteLine("Site exists: " + CheckIfSiteExists(siteUrl));
        }

        static bool CheckIfSiteExists(string url)
        {
            try
            {
                using (var client = new WebClient())
                {
                    try
                    {
                        string check = client.DownloadString(url.Trim().TrimEnd(new char[] { '/' }) + "/_layouts/15/settings.aspx"); //site's homepage might not always exist, so use settings page
                    }
                    catch (WebException wex)
                    {
                        var response = wex.Response as HttpWebResponse;
                        if (response != null && response.StatusCode == (HttpStatusCode)404)
                            return false;
                    }
                }
            }
            catch
            {
                //Ignore, as it will a 403 error even when the site exists because we don't authenticate in the webcall.
            }
            return true;
        }

    }
}
