﻿using Microsoft.SharePoint.Client;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Text;
using System.Threading;
using System.Threading.Tasks;

namespace KevinTimmerman.UC2016.ThrottlingAndOutages
{
    class Program
    {
        private static int numberOfThreads = 100;
        private static int numberOfCallsPerThread = 500;
        private static bool killSwitch = false;
        private static ManualResetEvent doneEvent;
        private static int threadsStarted = 0;
        private static int numberOfRequestsMade = 0;
        static void Main(string[] args)
        {
            // OfficeDevPnP.Core.PnPClientContext context = new OfficeDevPnP.Core.PnPClientContext(siteUrl, 5, 10)

            doneEvent = new ManualResetEvent(false);
            Console.Write(string.Format("Starting {0} threads with {1} requests per thread", numberOfThreads, numberOfCallsPerThread));
            for (int i = 0; i < numberOfThreads; i++)
            {
                if (killSwitch)
                    break;
                ThreadPool.QueueUserWorkItem(o => GetWebTitle());
            }
            Console.WriteLine("");
            doneEvent.WaitOne();
        }

        public static void GetWebTitle()
        {
            threadsStarted++;

            Console.Write("\rRunning Threads: " + threadsStarted);

            while (threadsStarted != numberOfThreads)
            {
                Thread.Sleep(100);
            }

            int i = 0;
            while (i < numberOfCallsPerThread)
            {
                string siteUrl = "https://kevintimmerman.sharepoint.com";
                var authManager = new OfficeDevPnP.Core.AuthenticationManager();

                using (ClientContext context = authManager.GetAppOnlyAuthenticatedContext(siteUrl, "YOUR CLIENT ID HERE", "YOUR CLIENT SECRET HERE"))
                {
                
                        context.Load(context.Web, w => w.Title);
                        ExecuteQueryWithIncrementalRetry(context, 5, 5000);
                        numberOfRequestsMade++;
                        Console.Write("\rExecuteQueries performed: " + numberOfRequestsMade);
                        //Console.Write(".");//context.Web.Title);
                }
            i++;
            }
        }

        // This is the extension method. 
        // The first parameter takes the "this" modifier
        // and specifies the type for which the method is defined. 
        /// <summary>
        /// Extension method to invoke execute query with retry and incremental back off.
        /// </summary>
        /// <param name="context"></param>
        /// <param name="retryCount">Maximum amount of retries before giving up.</param>
        /// <param name="delay">Initial delay in milliseconds.</param>
        public static void ExecuteQueryWithIncrementalRetry(ClientContext context, int retryCount, int delay)
        {
            int retryAttempts = 0;
            int backoffInterval = delay;
            if (retryCount <= 0)
                throw new ArgumentException("Provide a retry count greater than zero.");

            if (delay <= 0)
                throw new ArgumentException("Provide a delay greater than zero.");

            // Do while retry attempt is less than retry count
            while (retryAttempts < retryCount)
            {
                try
                {
                    if (!killSwitch)
                        context.ExecuteQuery();
                    return;

                }
                catch (WebException wex)
                {
                    var response = wex.Response as HttpWebResponse;
                    // Check if request was throttled - http status code 429
                    // Check is request failed due to server unavailable - http status code 503
                    if (response != null && (response.StatusCode == (HttpStatusCode)429 || response.StatusCode == (HttpStatusCode)503))
                    {
                        // Output status to console. Should be changed as Debug.WriteLine for production usage.
                        Console.WriteLine(string.Format("CSOM request frequency exceeded usage limits. Sleeping for {0} seconds before retrying.", 
                                        backoffInterval));

                        killSwitch = true;

                        //Add delay for retry
                        System.Threading.Thread.Sleep(backoffInterval);

                        //Add to retry count and increase delay.
                        retryAttempts++;
                        backoffInterval = backoffInterval * 2;
                    }
                    else
                    {
                        throw;
                    }
                }
            }
            throw new MaximumRetryAttemptedException(string.Format("Maximum retry attempts {0}, has be attempted.", retryCount));
        }
    }


    public class MaximumRetryAttemptedException : Exception
    {
        public MaximumRetryAttemptedException(string message)
            : base(message)
        {

        }
    }
}