﻿using Microsoft.SharePoint.Client;
using System;
using System.Collections.Generic;
using System.Linq;
using System.Runtime.Caching;
using System.Text;
using System.Threading;
using System.Threading.Tasks;

namespace KevinTimmerman.UC2016.TokenCaching
{
    class Program
    {
        static void Main(string[] args)
        {
            while (true)
            {
                Uri siteUrl = new Uri("https://kevintimmerman.sharepoint.com");
                using (ClientContext context = new ClientContext(siteUrl))
                {
                    context.AuthenticationMode = ClientAuthenticationMode.Anonymous;
                    context.FormDigestHandlingEnabled = false;
                    context.ExecutingWebRequest += delegate(object sender, WebRequestEventArgs webRequestEventArgs)
                    {
                        webRequestEventArgs.WebRequestExecutor.RequestHeaders["Authorization"] =
                            "Bearer " + GetToken(siteUrl, false);
                    };

                    context.Load(context.Web, w => w.Title);
                    context.ExecuteQuery();
                    Console.WriteLine(context.Web.Title);
                    Thread.Sleep(1000);
                }
            }
        }

        static string GetRealm(Uri url, bool retry)
        {
            string cacheKey = "Cache_Realm";
            ObjectCache cache = MemoryCache.Default;
            var realm = cache[cacheKey] as string;
            if (string.IsNullOrEmpty(realm))
            {
                Console.WriteLine("Getting new realm...");
                realm = TokenHelper.GetRealmFromTargetUrl(url);
                if (!string.IsNullOrEmpty(realm))
                    cache.Set(cacheKey, realm, new CacheItemPolicy() { AbsoluteExpiration = DateTimeOffset.Now.AddDays(7) });
                else if (!retry)
                    GetRealm(url, true); //retry once

                Console.WriteLine("Added new realm to cache: " + realm);
            }
            else
            {
                Console.WriteLine("Got realm from cache");
            }
            return realm;
        }

        static string GetToken(Uri targetSite, bool retry)
        {
            string cacheKey = "Cache_Token";
            ObjectCache cache = MemoryCache.Default;
            var token = cache[cacheKey] as string;
            if (string.IsNullOrEmpty(token))
            {
                Console.WriteLine("Getting new token...");
                string realm = GetRealm(targetSite, false);
                token = TokenHelper.GetAppOnlyAccessToken(TokenHelper.SharePointPrincipal, targetSite.Authority, realm).AccessToken;
                
                if (!string.IsNullOrEmpty(token))
                    cache.Set(cacheKey, token, new CacheItemPolicy() { AbsoluteExpiration = DateTimeOffset.Now.AddMinutes(50) }); // Token is valid for 60, allows some time to refresh
                else if (!retry)
                    GetToken(targetSite, true); //retry once

                Console.WriteLine("Added new token to cache: " + token);
            }
            else
            {
                Console.WriteLine("Got Token from cache.");
            }
            return token;
        }
    }
}